@@ -17,7 +17,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.6.7';
+    $VERSION = '2.8.0';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -204,15 +204,10 @@ sub read_config {
     }
 
     _pre_151( $version, \%SETTING );
-
     _pre_171( $version, \%SETTING );
-
     _pre_181( $version, \%SETTING );
-
     _pre_184( $version, \%SETTING );
-
     _pre_200( $version, \%SETTING );
-
     _pre_223( $version, \%SETTING );
 
     $logger->debug( Dumper( \%SETTING ) );
@@ -281,6 +276,8 @@ sub add_defaults {
         quality                             => 75,
         'image type'                        => undef,
         device                              => undef,
+        'cache-device-list'                 => TRUE,
+        'device list'                       => [],
         'device blacklist'                  => undef,
         frontend                            => 'libimage-sane-perl',
         'scan prefix'                       => $EMPTY,
